@@ -14,14 +14,19 @@ require Exporter;
 =head1 NAME
 
 Mojo::Zabbix - Mojo::Zabbix is a simple perl wrapper of Zabbix API. 
+
+Mojo::Zabix - 是对zabbix api函数的简单打包，以便更易于用perl脚本进行
+访问操作zabbix。目前仅支持认证和请求方法，可以用其进行create/get
+/update/delete/exists方法调用，见例子。本模块基于Mojo::useragent，结果
+可以用Mojo:DOM进行处理和内容提取。
  
 =head1 VERSION
  
-Version 0.02
+Version 0.03
  
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
